@@ -8,9 +8,9 @@ from pdm.cli.filters import GroupSelection
 from pdm.cli.hooks import HookManager
 from pdm.cli.options import (
     dry_run_option,
+    frozen_lockfile_option,
     install_group,
     lockfile_option,
-    no_lock_option,
     packages_group,
     prerelease_option,
     save_strategy_group,
@@ -34,7 +34,7 @@ class Command(BaseCommand):
     arguments = (
         *BaseCommand.arguments,
         lockfile_option,
-        no_lock_option,
+        frozen_lockfile_option,
         save_strategy_group,
         update_strategy_group,
         prerelease_option,
@@ -97,7 +97,7 @@ class Command(BaseCommand):
         no_editable: bool = False,
         no_self: bool = False,
         dry_run: bool = False,
-        prerelease: bool = False,
+        prerelease: bool | None = None,
         fail_fast: bool = False,
         hooks: HookManager | None = None,
     ) -> None:
@@ -118,7 +118,7 @@ class Command(BaseCommand):
         lock_groups = ["default"] if project.lockfile.empty() else project.lockfile.groups
         if lock_groups is not None and group not in lock_groups:
             if project.enable_write_lockfile:
-                project.core.ui.echo(f"Adding group [success]{group}[/] to lockfile", err=True, style="info")
+                project.core.ui.info(f"Adding group [success]{group}[/] to lockfile")
             lock_groups.append(group)
         if (
             group == "default"
@@ -128,15 +128,12 @@ class Command(BaseCommand):
             if editables:
                 raise PdmUsageError("Cannot add editables to the default or optional dependency group")
         for r in [parse_requirement(line, True) for line in editables] + [parse_requirement(line) for line in packages]:
-            if project.name and normalize_name(project.name) == r.key and not r.extras:
-                project.core.ui.echo(
-                    f"Package [req]{project.name}[/] is the project itself.",
-                    err=True,
-                    style="warning",
-                )
+            if project.is_distribution and normalize_name(name := project.name) == r.key and not r.extras:
+                project.core.ui.warn(f"Package [req]{name}[/] is the project itself.")
                 continue
             if r.is_file_or_url:
                 r.relocate(project.backend)  # type: ignore[attr-defined]
+            r.groups = [group]
             key = r.identify()
             r.prerelease = prerelease
             tracked_names.add(key)
